summaryrefslogtreecommitdiffstats
path: root/libkdepim
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim')
-rw-r--r--libkdepim/addresseeemailselection.cpp10
-rw-r--r--libkdepim/addresseelineedit.cpp36
-rw-r--r--libkdepim/addresseeselector.cpp10
-rw-r--r--libkdepim/addresseeview.cpp112
-rw-r--r--libkdepim/addressesdialog.cpp2
-rw-r--r--libkdepim/broadcaststatus.cpp24
-rw-r--r--libkdepim/completionordereditor.cpp10
-rw-r--r--libkdepim/csshelper.cpp54
-rw-r--r--libkdepim/designerfields.cpp14
-rw-r--r--libkdepim/distributionlist.cpp2
-rw-r--r--libkdepim/embeddedurlpage.cpp4
-rw-r--r--libkdepim/htmldiffalgodisplay.cpp22
-rw-r--r--libkdepim/kaddrbook.cpp6
-rw-r--r--libkdepim/kcmdesignerfields.cpp32
-rw-r--r--libkdepim/kdateedit.cpp8
-rw-r--r--libkdepim/kdepim.widgets2
-rw-r--r--libkdepim/kfileio.cpp54
-rw-r--r--libkdepim/kfoldertree.cpp8
-rw-r--r--libkdepim/kincidencechooser.cpp8
-rw-r--r--libkdepim/komposer/core/pluginmanager.cpp2
-rw-r--r--libkdepim/komposer/plugins/default/defaulteditor.cpp4
-rw-r--r--libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp2
-rw-r--r--libkdepim/kpixmapregionselectorwidget.cpp18
-rw-r--r--libkdepim/kprefsdialog.cpp2
-rw-r--r--libkdepim/kregexp3.cpp10
-rw-r--r--libkdepim/kscoring.cpp16
-rw-r--r--libkdepim/kscoringeditor.cpp2
-rw-r--r--libkdepim/ksubscription.cpp2
-rw-r--r--libkdepim/ktimeedit.cpp6
-rw-r--r--libkdepim/kwidgetlister.cpp2
-rw-r--r--libkdepim/ldapclient.cpp56
-rw-r--r--libkdepim/ldapsearchdialog.cpp22
-rw-r--r--libkdepim/linklocator.cpp6
-rw-r--r--libkdepim/overlaywidget.cpp2
-rw-r--r--libkdepim/qutf7codec.cpp2
-rw-r--r--libkdepim/sendsmsdialog.cpp8
-rw-r--r--libkdepim/statusbarprogresswidget.cpp2
37 files changed, 291 insertions, 291 deletions
diff --git a/libkdepim/addresseeemailselection.cpp b/libkdepim/addresseeemailselection.cpp
index 481fc155..589e7e33 100644
--- a/libkdepim/addresseeemailselection.cpp
+++ b/libkdepim/addresseeemailselection.cpp
@@ -143,8 +143,8 @@ bool AddresseeEmailSelection::itemEnabled( const KABC::Addressee &addressee, uin
bool AddresseeEmailSelection::itemMatches( const KABC::Addressee &addressee, uint index, const TQString &pattern ) const
{
- return addressee.formattedName().startsWith( pattern, false ) ||
- email( addressee, index ).startsWith( pattern, false );
+ return addressee.formattedName().tqstartsWith( pattern, false ) ||
+ email( addressee, index ).tqstartsWith( pattern, false );
}
bool AddresseeEmailSelection::itemEquals( const KABC::Addressee &addressee, uint index, const TQString &pattern ) const
@@ -172,13 +172,13 @@ bool AddresseeEmailSelection::distributionListMatches( const KABC::DistributionL
const TQString &pattern ) const
{
// check whether the name of the distribution list matches the pattern or one of its entries.
- bool ok = distributionList->name().startsWith( pattern, false );
+ bool ok = distributionList->name().tqstartsWith( pattern, false );
KABC::DistributionList::Entry::List entries = distributionList->entries();
KABC::DistributionList::Entry::List::ConstIterator it;
for ( it = entries.begin(); it != entries.end(); ++it ) {
- ok = ok || (*it).addressee.formattedName().startsWith( pattern, false ) ||
- (*it).email.startsWith( pattern, false );
+ ok = ok || (*it).addressee.formattedName().tqstartsWith( pattern, false ) ||
+ (*it).email.tqstartsWith( pattern, false );
}
return ok;
diff --git a/libkdepim/addresseelineedit.cpp b/libkdepim/addresseelineedit.cpp
index 0d86fad4..9e42085b 100644
--- a/libkdepim/addresseelineedit.cpp
+++ b/libkdepim/addresseelineedit.cpp
@@ -217,12 +217,12 @@ void AddresseeLineEdit::keyPressEvent( TQKeyEvent *e )
{
bool accept = false;
- if ( KStdAccel::shortcut( KStdAccel::SubstringCompletion ).tqcontains( KKey( e ) ) ) {
+ if ( KStdAccel::shortcut( KStdAccel::SubstringCompletion ).contains( KKey( e ) ) ) {
//TODO: add LDAP substring lookup, when it becomes available in KPIM::LDAPSearch
updateSearchString();
doCompletion( true );
accept = true;
- } else if ( KStdAccel::shortcut( KStdAccel::TextCompletion ).tqcontains( KKey( e ) ) ) {
+ } else if ( KStdAccel::shortcut( KStdAccel::TextCompletion ).contains( KKey( e ) ) ) {
int len = text().length();
if ( len == cursorPosition() ) { // at End?
@@ -344,9 +344,9 @@ void AddresseeLineEdit::mouseReleaseEvent( TQMouseEvent *e )
{
// reimplemented from TQLineEdit::mouseReleaseEvent()
if ( m_useCompletion
- && TQApplication::clipboard()->supportsSelection()
+ && TQApplication::tqclipboard()->supportsSelection()
&& !isReadOnly()
- && e->button() == MidButton ) {
+ && e->button() == Qt::MidButton ) {
m_smartPaste = true;
}
@@ -727,7 +727,7 @@ void AddresseeLineEdit::addContact( const KABC::Addressee& addr, int weight, int
bool bDone = false;
int i = -1;
- while( ( i = name.findRev(' ') ) > 1 && !bDone ) {
+ while( ( i = name.tqfindRev(' ') ) > 1 && !bDone ) {
TQString sLastName( name.mid( i+1 ) );
if( ! sLastName.isEmpty() &&
2 <= sLastName.length() && // last names must be at least 2 chars long
@@ -763,7 +763,7 @@ void AddresseeLineEdit::addCompletionItem( const TQString& string, int weight, i
weight = TQMAX( ( *it ).first, weight );
( *it ).first = weight;
} else {
- s_completionItemMap->insert( string, qMakePair( weight, completionItemSource ) );
+ s_completionItemMap->insert( string, tqMakePair( weight, completionItemSource ) );
}
if ( keyWords == 0 )
s_completion->addItem( string, weight );
@@ -798,7 +798,7 @@ void AddresseeLineEdit::startLoadingLDAPEntries()
TQString s( *s_LDAPText );
// TODO cache last?
TQString prevAddr;
- int n = s.findRev( ',' );
+ int n = s.tqfindRev( ',' );
if ( n >= 0 ) {
prevAddr = s.left( n + 1 ) + ' ';
s = s.mid( n + 1, 255 ).stripWhiteSpace();
@@ -872,13 +872,13 @@ void AddresseeLineEdit::setCompletedItems( const TQStringList& items, bool autoS
// item, if there is one
TQListBoxItem* item = 0;
if ( oldCurrentText.isEmpty()
- || ( item = completionBox->findItem( oldCurrentText ) ) == 0 ) {
+ || ( item = completionBox->tqfindItem( oldCurrentText ) ) == 0 ) {
item = completionBox->item( 1 );
}
if ( item )
{
if ( itemUnderMouse ) {
- TQListBoxItem *newItemUnderMouse = completionBox->findItem( oldTextUnderMouse );
+ TQListBoxItem *newItemUnderMouse = completionBox->tqfindItem( oldTextUnderMouse );
// if the mouse was over an item, before, but now that's elsewhere,
// move the cursor, so folks don't accidently click the wrong item
if ( newItemUnderMouse ) {
@@ -1026,7 +1026,7 @@ int KPIM::AddresseeLineEdit::addCompletionSource( const TQString &source, int we
else
(*s_completionSourceWeights)[source] = weight;
- int sourceIndex = s_completionSources->findIndex( source );
+ int sourceIndex = s_completionSources->tqfindIndex( source );
if ( sourceIndex == -1 ) {
s_completionSources->append( source );
return s_completionSources->size() - 1;
@@ -1037,12 +1037,12 @@ int KPIM::AddresseeLineEdit::addCompletionSource( const TQString &source, int we
bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
{
- if ( obj == completionBox() ) {
+ if ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(completionBox()) ) {
if ( e->type() == TQEvent::MouseButtonPress ||
e->type() == TQEvent::MouseMove ||
e->type() == TQEvent::MouseButtonRelease ||
e->type() == TQEvent::MouseButtonDblClick ) {
- TQMouseEvent* me = static_cast<TQMouseEvent*>( e );
+ TQMouseEvent* me = TQT_TQMOUSEEVENT( e );
// find list box item at the event position
TQListBoxItem *item = completionBox()->itemAt( me->pos() );
if ( !item ) {
@@ -1054,8 +1054,8 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
// avoid selection of headers on button press, or move or release while
// a button is pressed
if ( e->type() == TQEvent::MouseButtonPress
- || me->state() & LeftButton || me->state() & MidButton
- || me->state() & RightButton ) {
+ || me->state() & Qt::LeftButton || me->state() & Qt::MidButton
+ || me->state() & Qt::RightButton ) {
if ( itemIsHeader(item) ) {
return true; // eat the event, we don't want anything to happen
} else {
@@ -1070,18 +1070,18 @@ bool KPIM::AddresseeLineEdit::eventFilter(TQObject *obj, TQEvent *e)
}
}
}
- if ( ( obj == this ) &&
+ if ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this) ) &&
( e->type() == TQEvent::AccelOverride ) ) {
- TQKeyEvent *ke = static_cast<TQKeyEvent*>( e );
+ TQKeyEvent *ke = TQT_TQKEYEVENT( e );
if ( ke->key() == Key_Up || ke->key() == Key_Down || ke->key() == Key_Tab ) {
ke->accept();
return true;
}
}
- if ( ( obj == this ) &&
+ if ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this) ) &&
( e->type() == TQEvent::KeyPress || e->type() == TQEvent::KeyRelease ) &&
completionBox()->isVisible() ) {
- TQKeyEvent *ke = static_cast<TQKeyEvent*>( e );
+ TQKeyEvent *ke = TQT_TQKEYEVENT( e );
int currentIndex = completionBox()->currentItem();
if ( currentIndex < 0 ) {
return true;
diff --git a/libkdepim/addresseeselector.cpp b/libkdepim/addresseeselector.cpp
index c7e37817..70d587ba 100644
--- a/libkdepim/addresseeselector.cpp
+++ b/libkdepim/addresseeselector.cpp
@@ -227,8 +227,8 @@ class SelectionViewItem : public TQListViewItem
AddresseeSelector::AddresseeSelector( Selection *selection, TQWidget *tqparent, const char *name )
: TQWidget( tqparent, name ), mSelection( selection ), mManager( 0 )
{
- mMoveMapper = new TQSignalMapper( this );
- mRemoveMapper = new TQSignalMapper( this );
+ mMoveMapper = new TQSignalMapper( TQT_TQOBJECT(this) );
+ mRemoveMapper = new TQSignalMapper( TQT_TQOBJECT(this) );
mAddressBookManager = new AddressBookManager();
@@ -300,7 +300,7 @@ void AddresseeSelector::initGUI()
connect( listView, TQT_SIGNAL( doubleClicked( TQListViewItem*, const TQPoint&, int ) ),
mRemoveMapper, TQT_SLOT( map() ) );
- mRemoveMapper->setMapping( listView, i );
+ mRemoveMapper->setMapping( TQT_TQOBJECT(listView), i );
TQVBoxLayout *buttonLayout = new TQVBoxLayout( this );
buttonLayout->tqsetAlignment( TQt::AlignBottom );
@@ -313,7 +313,7 @@ void AddresseeSelector::initGUI()
connect( moveButton, TQT_SIGNAL( clicked() ),
mMoveMapper, TQT_SLOT( map() ) );
- mMoveMapper->setMapping( moveButton, i );
+ mMoveMapper->setMapping( TQT_TQOBJECT(moveButton), i );
// remove button
TQToolButton *removeButton = new TQToolButton( this );
@@ -322,7 +322,7 @@ void AddresseeSelector::initGUI()
connect( removeButton, TQT_SIGNAL( clicked() ),
mRemoveMapper, TQT_SLOT( map() ) );
- mRemoveMapper->setMapping( removeButton, i );
+ mRemoveMapper->setMapping( TQT_TQOBJECT(removeButton), i );
buttonLayout->addWidget( moveButton );
buttonLayout->addWidget( removeButton );
diff --git a/libkdepim/addressesdialog.cpp b/libkdepim/addressesdialog.cpp
index b7bea236..e874ac01 100644
--- a/libkdepim/addressesdialog.cpp
+++ b/libkdepim/addressesdialog.cpp
@@ -912,7 +912,7 @@ AddressesDialog::saveAs()
KMessageBox::information( 0,
i18n( "<qt>Distribution list with the given name <b>%1</b> "
"already exists. Please select a different name.</qt>" )
- .arg( name ) );
+ .tqarg( name ) );
return;
}
diff --git a/libkdepim/broadcaststatus.cpp b/libkdepim/broadcaststatus.cpp
index 68900936..e3f16c32 100644
--- a/libkdepim/broadcaststatus.cpp
+++ b/libkdepim/broadcaststatus.cpp
@@ -57,9 +57,9 @@ void BroadcastqStatus::seStatusMsgWithTimestamp( const TQString& message )
{
KLocale* locale = KGlobal::locale();
seStatusMsg( i18n( "%1 is a time, %2 is a status message", "[%1] %2" )
- .arg( locale->formatTime( TQTime::currentTime(),
+ .tqarg( locale->formatTime( TQTime::currentTime(),
true /* with seconds */ ) )
- .arg( message ) );
+ .tqarg( message ) );
}
void BroadcastqStatus::seStatusMsgTransmissionCompleted( int numMessages,
@@ -78,13 +78,13 @@ void BroadcastqStatus::seStatusMsgTransmissionCompleted( int numMessages,
"Transmission complete. %n new messages in %1 KB "
"(%2 KB remaining on the server).",
numMessages )
- .arg( numBytesRead / 1024 )
- .arg( numBytes / 1024 );
+ .tqarg( numBytesRead / 1024 )
+ .tqarg( numBytes / 1024 );
else
statusMsg = i18n( "Transmission complete. %n message in %1 KB.",
"Transmission complete. %n messages in %1 KB.",
numMessages )
- .arg( numBytesRead / 1024 );
+ .tqarg( numBytesRead / 1024 );
}
else
statusMsg = i18n( "Transmission complete. %n new message.",
@@ -118,17 +118,17 @@ void BroadcastqStatus::seStatusMsgTransmissionCompleted( const TQString& account
"%n new messages in %1 KB "
"(%2 KB remaining on the server).",
numMessages )
- .arg( numBytesRead / 1024 )
- .arg( numBytes / 1024 )
- .arg( account );
+ .tqarg( numBytesRead / 1024 )
+ .tqarg( numBytes / 1024 )
+ .tqarg( account );
else
statusMsg = i18n( "Transmission for account %2 complete. "
"%n message in %1 KB.",
"Transmission for account %2 complete. "
"%n messages in %1 KB.",
numMessages )
- .arg( numBytesRead / 1024 )
- .arg( account );
+ .tqarg( numBytesRead / 1024 )
+ .tqarg( account );
}
else
statusMsg = i18n( "Transmission for account %1 complete. "
@@ -136,11 +136,11 @@ void BroadcastqStatus::seStatusMsgTransmissionCompleted( const TQString& account
"Transmission for account %1 complete. "
"%n new messages.",
numMessages )
- .arg( account );
+ .tqarg( account );
}
else
statusMsg = i18n( "Transmission for account %1 complete. No new messages.")
- .arg( account );
+ .tqarg( account );
seStatusMsgWithTimestamp( statusMsg );
if ( item )
diff --git a/libkdepim/completionordereditor.cpp b/libkdepim/completionordereditor.cpp
index e4821f3d..9d4d19bd 100644
--- a/libkdepim/completionordereditor.cpp
+++ b/libkdepim/completionordereditor.cpp
@@ -88,7 +88,7 @@ class LDAPCompletionItem : public CompletionItem
{
public:
LDAPCompletionItem( LdapClient* ldapClient ) : mLdapClient( ldapClient ) {}
- virtual TQString label() const { return i18n( "LDAP server %1" ).arg( mLdapClient->server().host() ); }
+ virtual TQString label() const { return i18n( "LDAP server %1" ).tqarg( mLdapClient->server().host() ); }
virtual int completionWeight() const { return mLdapClient->completionWeight(); }
virtual void save( CompletionOrderEditor* );
protected:
@@ -102,7 +102,7 @@ void LDAPCompletionItem::save( CompletionOrderEditor* )
{
KConfig * config = LdapSearch::config();
config->setGroup( "LDAP" );
- config->writeEntry( TQString( "SelectedCompletionWeight%1" ).arg( mLdapClient->clientNumber() ),
+ config->writeEntry( TQString( "SelectedCompletionWeight%1" ).tqarg( mLdapClient->clientNumber() ),
mWeight );
config->sync();
}
@@ -141,7 +141,7 @@ public:
KABCImapSubResCompletionItem( ResourceABC* resource, const TQString& subResource )
: mResource( resource ), mSubResource( subResource ), mWeight( completionWeight() ) {}
virtual TQString label() const {
- return TQString( "%1 %2" ).arg( mResource->resourceName() ).arg( mResource->subresourceLabel( mSubResource ) );
+ return TQString( "%1 %2" ).tqarg( mResource->resourceName() ).tqarg( mResource->subresourceLabel( mSubResource ) );
}
virtual int completionWeight() const {
return mResource->subresourceCompletionWeight( mSubResource );
@@ -225,12 +225,12 @@ CompletionOrderEditor::CompletionOrderEditor( KPIM::LdapSearch* ldapSearch,
mUpButton = new KPushButton( upDownBox, "mUpButton" );
mUpButton->setIconSet( BarIconSet( "up", KIcon::SizeSmall ) );
mUpButton->setEnabled( false ); // b/c no item is selected yet
- mUpButton->setFocusPolicy( StrongFocus );
+ mUpButton->setFocusPolicy( Qt::StrongFocus );
mDownButton = new KPushButton( upDownBox, "mDownButton" );
mDownButton->setIconSet( BarIconSet( "down", KIcon::SizeSmall ) );
mDownButton->setEnabled( false ); // b/c no item is selected yet
- mDownButton->setFocusPolicy( StrongFocus );
+ mDownButton->setFocusPolicy( Qt::StrongFocus );
TQWidget* spacer = new TQWidget( upDownBox );
upDownBox->setStretchFactor( spacer, 100 );
diff --git a/libkdepim/csshelper.cpp b/libkdepim/csshelper.cpp
index f828476f..05f20e39 100644
--- a/libkdepim/csshelper.cpp
+++ b/libkdepim/csshelper.cpp
@@ -73,10 +73,10 @@ namespace KPIM {
mMetrics( pdm )
{
// initialize with defaults - should match the corresponding application defaults
- mForegroundColor = TQApplication::palette().active().text();
+ mForegroundColor = TQApplication::tqpalette().active().text();
mLinkColor = KGlobalSettings::linkColor();
mVisitedLinkColor = KGlobalSettings::visitedLinkColor();
- mBackgroundColor = TQApplication::palette().active().base();
+ mBackgroundColor = TQApplication::tqpalette().active().base();
cHtmlWarning = TQColor( 0xFF, 0x40, 0x40 ); // warning frame color: light red
cPgpEncrH = TQColor( 0x00, 0x80, 0xFF ); // light blue
@@ -184,9 +184,9 @@ namespace KPIM {
? level % numQuoteLevels + 1
: kMin( level + 1, numQuoteLevels ) ;
if ( level >= numQuoteLevels )
- return TQString( "<div class=\"deepquotelevel%1\">" ).arg( effectiveLevel );
+ return TQString( "<div class=\"deepquotelevel%1\">" ).tqarg( effectiveLevel );
else
- return TQString( "<div class=\"quotelevel%1\">" ).arg( effectiveLevel );
+ return TQString( "<div class=\"quotelevel%1\">" ).tqarg( effectiveLevel );
}
TQString CSSHelper::nonQuotedFontTag() const {
@@ -214,9 +214,9 @@ namespace KPIM {
TQString CSSHelper::printCssDefinitions( bool fixed ) const {
const TQString headerFont = TQString( " font-family: \"%1\" ! important;\n"
" font-size: %2pt ! important;\n" )
- .arg( mPrintFont.family() )
- .arg( mPrintFont.pointSize() );
- const TQColorGroup & cg = TQApplication::palette().active();
+ .tqarg( mPrintFont.family() )
+ .tqarg( mPrintFont.pointSize() );
+ const TQColorGroup & cg = TQApplication::tqpalette().active();
const TQFont printFont = bodyFont( fixed, true /* print */ );
TQString quoteCSS;
@@ -234,7 +234,7 @@ namespace KPIM {
" color: #000000 ! important;\n"
" background-color: #ffffff ! important\n"
"}\n\n" )
- .arg( printFont.family(),
+ .tqarg( printFont.family(),
TQString::number( printFont.pointSize() ) )
+
TQString( "tr.textAtmH,\n"
@@ -288,7 +288,7 @@ namespace KPIM {
" display:none ! important;\n"
"}\n\n"
)
- .arg( headerFont,
+ .tqarg( headerFont,
cg.background().name(),
cg.foreground().name() )
+ quoteCSS;
@@ -300,15 +300,15 @@ namespace KPIM {
const TQString linkColor = mLinkColor.name();
const TQString headerFont = TQString(" font-family: \"%1\" ! important;\n"
" font-size: %2px ! important;\n")
- .arg( mBodyFont.family() )
- .arg( pointsToPixel( helper->mMetrics, mBodyFont.pointSize() ) );
+ .tqarg( mBodyFont.family() )
+ .tqarg( pointsToPixel( helper->mMetrics, mBodyFont.pointSize() ) );
const TQString background = ( mBackingPixmapOn
? TQString( " background-image:url(file://%1) ! important;\n" )
- .arg( mBackingPixmapStr )
+ .tqarg( mBackingPixmapStr )
: TQString( " background-color: %1 ! important;\n" )
- .arg( bgColor ) );
+ .tqarg( bgColor ) );
const TQString bodyFontSize = TQString::number( pointsToPixel( helper->mMetrics, fontSize( fixed ) ) ) + "px" ;
- const TQColorGroup & cg = TQApplication::palette().active();
+ const TQColorGroup & cg = TQApplication::tqpalette().active();
TQString quoteCSS;
if ( bodyFont( fixed ).italic() )
@@ -322,7 +322,7 @@ namespace KPIM {
for ( int i = 0 ; i < 3 ; ++i ) {
quoteCSS += TQString( "div.quotelevel%1 {\n"
" color: %2 ! important;\n" )
- .arg( TQString::number(i+1), mQuoteColor[i].name() );
+ .tqarg( TQString::number(i+1), mQuoteColor[i].name() );
if ( mQuoteFont[i].italic() )
quoteCSS += " font-style: italic ! important;\n";
if ( mQuoteFont[i].bold() )
@@ -337,7 +337,7 @@ namespace KPIM {
for ( int i = 0 ; i < 3 ; ++i ) {
quoteCSS += TQString( "div.deepquotelevel%1 {\n"
" color: %2 ! important;\n" )
- .arg( TQString::number(i+1), mQuoteColor[i].name() );
+ .tqarg( TQString::number(i+1), mQuoteColor[i].name() );
if ( mQuoteFont[i].italic() )
quoteCSS += " font-style: italic ! important;\n";
if ( mQuoteFont[i].bold() )
@@ -354,7 +354,7 @@ namespace KPIM {
" color: %3 ! important;\n"
"%4"
"}\n\n" )
- .arg( bodyFont( fixed ).family(),
+ .tqarg( bodyFont( fixed ).family(),
bodyFontSize,
fgColor,
background )
@@ -392,7 +392,7 @@ namespace KPIM {
"tr.rfc822H {\n"
"%4"
"}\n\n" )
- .arg( linkColor, fgColor, bgColor, headerFont )
+ .tqarg( linkColor, fgColor, bgColor, headerFont )
+
TQString( "table.encr {\n"
" background-color: %1 ! important;\n"
@@ -404,7 +404,7 @@ namespace KPIM {
"}\n\n"
"tr.encrB { background-color: %4 ! important; }\n\n" )
- .arg( cPgpEncrF.name(),
+ .tqarg( cPgpEncrF.name(),
cPgpEncrH.name(),
headerFont,
cPgpEncrB.name() )
@@ -419,7 +419,7 @@ namespace KPIM {
"}\n\n"
"tr.signOkKeyOkB { background-color: %4 ! important; }\n\n" )
- .arg( cPgpOk1F.name(),
+ .tqarg( cPgpOk1F.name(),
cPgpOk1H.name(),
headerFont,
cPgpOk1B.name() )
@@ -434,7 +434,7 @@ namespace KPIM {
"}\n\n"
"tr.signOkKeyBadB { background-color: %4 ! important; }\n\n" )
- .arg( cPgpOk0F.name(),
+ .tqarg( cPgpOk0F.name(),
cPgpOk0H.name(),
headerFont,
cPgpOk0B.name() )
@@ -449,7 +449,7 @@ namespace KPIM {
"}\n\n"
"tr.signWarnB { background-color: %4 ! important; }\n\n" )
- .arg( cPgpWarnF.name(),
+ .tqarg( cPgpWarnF.name(),
cPgpWarnH.name(),
headerFont,
cPgpWarnB.name() )
@@ -464,7 +464,7 @@ namespace KPIM {
"}\n\n"
"tr.signErrB { background-color: %4 ! important; }\n\n" )
- .arg( cPgpErrF.name(),
+ .tqarg( cPgpErrF.name(),
cPgpErrH.name(),
headerFont,
cPgpErrB.name() )
@@ -472,7 +472,7 @@ namespace KPIM {
TQString( "div.htmlWarn {\n"
" border: 2px solid %1 ! important;\n"
"}\n\n" )
- .arg( cHtmlWarning.name() )
+ .tqarg( cHtmlWarning.name() )
+
TQString( "div.header {\n"
"%1"
@@ -519,12 +519,12 @@ namespace KPIM {
"}\n\n"
)
- .arg( headerFont )
- .arg( cg.highlight().name(),
+ .tqarg( headerFont )
+ .tqarg( cg.highlight().name(),
cg.highlightedText().name(),
cg.foreground().name(),
cg.background().name() )
- .arg( cg.mid().name() )
+ .tqarg( cg.mid().name() )
+ quoteCSS;
}
diff --git a/libkdepim/designerfields.cpp b/libkdepim/designerfields.cpp
index 6907485d..31a3b7f8 100644
--- a/libkdepim/designerfields.cpp
+++ b/libkdepim/designerfields.cpp
@@ -83,7 +83,7 @@ void DesignerFields::initGUI( const TQString &uiFile )
if ( name.startsWith( "X_" ) ) {
name = name.mid( 2 );
- TQWidget *widget = static_cast<TQWidget*>( it.current() );
+ TQWidget *widget = TQT_TQWIDGET( it.current() );
if ( !name.isEmpty() )
mWidgets.insert( name, widget );
@@ -187,13 +187,13 @@ void DesignerFields::load( DesignerFields::Storage *storage )
wdg->setChecked( value == "true" || value == "1" );
} else if ( it.data()->inherits( TQDATETIMEEDIT_OBJECT_NAME_STRING ) ) {
TQDateTimeEdit *wdg = static_cast<TQDateTimeEdit*>( it.data() );
- wdg->setDateTime( TQDateTime::fromString( value, TQt::ISODate ) );
+ wdg->setDateTime( TQDateTime::fromString( value, Qt::ISODate ) );
} else if ( it.data()->inherits( "KDateTimeWidget" ) ) {
KDateTimeWidget *wdg = static_cast<KDateTimeWidget*>( it.data() );
- wdg->setDateTime( TQDateTime::fromString( value, TQt::ISODate ) );
+ wdg->setDateTime( TQDateTime::fromString( value, Qt::ISODate ) );
} else if ( it.data()->inherits( "KDatePicker" ) ) {
KDatePicker *wdg = static_cast<KDatePicker*>( it.data() );
- wdg->setDate( TQDate::fromString( value, TQt::ISODate ) );
+ wdg->setDate( TQDate::fromString( value, Qt::ISODate ) );
} else if ( it.data()->inherits( TQCOMBOBOX_OBJECT_NAME_STRING ) ) {
TQComboBox *wdg = static_cast<TQComboBox*>( it.data() );
wdg->setCurrentText( value );
@@ -221,13 +221,13 @@ void DesignerFields::save( DesignerFields::Storage *storage )
value = ( wdg->isChecked() ? "true" : "false" );
} else if ( it.data()->inherits( TQDATETIMEEDIT_OBJECT_NAME_STRING ) ) {
TQDateTimeEdit *wdg = static_cast<TQDateTimeEdit*>( it.data() );
- value = wdg->dateTime().toString( TQt::ISODate );
+ value = wdg->dateTime().toString( Qt::ISODate );
} else if ( it.data()->inherits( "KDateTimeWidget" ) ) {
KDateTimeWidget *wdg = static_cast<KDateTimeWidget*>( it.data() );
- value = wdg->dateTime().toString( TQt::ISODate );
+ value = wdg->dateTime().toString( Qt::ISODate );
} else if ( it.data()->inherits( "KDatePicker" ) ) {
KDatePicker *wdg = static_cast<KDatePicker*>( it.data() );
- value = wdg->date().toString( TQt::ISODate );
+ value = wdg->date().toString( Qt::ISODate );
} else if ( it.data()->inherits( TQCOMBOBOX_OBJECT_NAME_STRING ) ) {
TQComboBox *wdg = static_cast<TQComboBox*>( it.data() );
value = wdg->currentText();
diff --git a/libkdepim/distributionlist.cpp b/libkdepim/distributionlist.cpp
index 97b11bcf..4cf079c7 100644
--- a/libkdepim/distributionlist.cpp
+++ b/libkdepim/distributionlist.cpp
@@ -44,7 +44,7 @@ static ParseList parseCustom( const TQString& str )
Q_ASSERT( helpList.count() < 3 ); // 1 or 2 items, but not more
const TQString uid = helpList.first();
const TQString email = helpList.last();
- res.append( qMakePair( uid, email ) );
+ res.append( tqMakePair( uid, email ) );
}
return res;
}
diff --git a/libkdepim/embeddedurlpage.cpp b/libkdepim/embeddedurlpage.cpp
index e73911f0..d45d532d 100644
--- a/libkdepim/embeddedurlpage.cpp
+++ b/libkdepim/embeddedurlpage.cpp
@@ -43,7 +43,7 @@ void EmbeddedURLPage::initGUI( const TQString &url, const TQString &/*mimetype*/
{
TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
tqlayout->setAutoAdd( true );
- new TQLabel( i18n("Showing URL %1").arg( url ), this );
+ new TQLabel( i18n("Showing URL %1").tqarg( url ), this );
}
void EmbeddedURLPage::loadContents()
@@ -55,7 +55,7 @@ void EmbeddedURLPage::loadContents()
if ( mimetype == "auto" )
mimetype == KMimeType::findByURL( mUri )->name();
// "this" is both the tqparent widget and the tqparent object
- mPart = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), this, 0, this, 0 );
+ mPart = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), TQT_TQWIDGET(this), 0, TQT_TQOBJECT(this), 0 );
if ( mPart ) {
mPart->openURL( mUri );
mPart->widget()->show();
diff --git a/libkdepim/htmldiffalgodisplay.cpp b/libkdepim/htmldiffalgodisplay.cpp
index 19b99d4e..124f2387 100644
--- a/libkdepim/htmldiffalgodisplay.cpp
+++ b/libkdepim/htmldiffalgodisplay.cpp
@@ -45,13 +45,13 @@ void HTMLDiffAlgoDisplay::begin()
mText.append( "<html>" );
mText.append( TQString( "<body text=\"%1\" bgcolor=\"%2\">" )
- .arg( KGlobalSettings::textColor().name() )
- .arg( KGlobalSettings::baseColor().name() ) );
+ .tqarg( KGlobalSettings::textColor().name() )
+ .tqarg( KGlobalSettings::baseColor().name() ) );
mText.append( "<center><table>" );
mText.append( TQString( "<tr><th></th><th align=\"center\">%1</th><td> </td><th align=\"center\">%2</th></tr>" )
- .arg( mLeftTitle )
- .arg( mRightTitle ) );
+ .tqarg( mLeftTitle )
+ .tqarg( mRightTitle ) );
}
void HTMLDiffAlgoDisplay::end()
@@ -76,22 +76,22 @@ void HTMLDiffAlgoDisplay::setRightSourceTitle( const TQString &title )
void HTMLDiffAlgoDisplay::additionalLeftField( const TQString &id, const TQString &value )
{
mText.append( TQString( "<tr><td align=\"right\"><b>%1:</b></td><td bgcolor=\"#9cff83\">%2</td><td></td><td></td></tr>" )
- .arg( id )
- .arg( textToHTML( value ) ) );
+ .tqarg( id )
+ .tqarg( textToHTML( value ) ) );
}
void HTMLDiffAlgoDisplay::additionalRightField( const TQString &id, const TQString &value )
{
mText.append( TQString( "<tr><td align=\"right\"><b>%1:</b></td><td></td><td></td><td bgcolor=\"#9cff83\">%2</td></tr>" )
- .arg( id )
- .arg( textToHTML( value ) ) );
+ .tqarg( id )
+ .tqarg( textToHTML( value ) ) );
}
void HTMLDiffAlgoDisplay::conflictField( const TQString &id, const TQString &leftValue,
const TQString &rightValue )
{
mText.append( TQString( "<tr><td align=\"right\"><b>%1:</b></td><td bgcolor=\"#ff8686\">%2</td><td></td><td bgcolor=\"#ff8686\">%3</td></tr>" )
- .arg( id )
- .arg( textToHTML( leftValue ) )
- .arg( textToHTML( rightValue ) ) );
+ .tqarg( id )
+ .tqarg( textToHTML( leftValue ) )
+ .tqarg( textToHTML( rightValue ) ) );
}
diff --git a/libkdepim/kaddrbook.cpp b/libkdepim/kaddrbook.cpp
index 7356bc2d..3a0c7dc0 100644
--- a/libkdepim/kaddrbook.cpp
+++ b/libkdepim/kaddrbook.cpp
@@ -74,7 +74,7 @@ void KAddrBookExternal::openEmail( const TQString &addr, TQWidget *tqparent ) {
//TODO: Enable the better message at the next string unfreeze
#if 0
TQString text = i18n("<qt>The email address <b>%1</b> cannot be "
- "found in your addressbook.</qt>").arg( email );
+ "found in your addressbook.</qt>").tqarg( email );
#else
TQString text = email + " " + i18n( "is not in address book" );
#endif
@@ -150,12 +150,12 @@ void KAddrBookExternal::addEmail( const TQString& addr, TQWidget *tqparent) {
if ( KAddrBookExternal::addAddressee( a ) ) {
TQString text = i18n("<qt>The email address <b>%1</b> was added to your "
"addressbook; you can add more information to this "
- "entry by opening the addressbook.</qt>").arg( addr );
+ "entry by opening the addressbook.</qt>").tqarg( addr );
KMessageBox::information( tqparent, text, TQString(), "addedtokabc" );
}
} else {
TQString text = i18n("<qt>The email address <b>%1</b> is already in your "
- "addressbook.</qt>").arg( addr );
+ "addressbook.</qt>").tqarg( addr );
KMessageBox::information( tqparent, text, TQString(),
"alreadyInAddressBook" );
}
diff --git a/libkdepim/kcmdesignerfields.cpp b/libkdepim/kcmdesignerfields.cpp
index be4aa97b..10edf6f8 100644
--- a/libkdepim/kcmdesignerfields.cpp
+++ b/libkdepim/kcmdesignerfields.cpp
@@ -60,14 +60,14 @@ class PageItem : public TQCheckListItem
: TQCheckListItem( tqparent, "", TQCheckListItem::CheckBox ),
mPath( path ), mIsActive( false )
{
- mName = path.mid( path.findRev( '/' ) + 1 );
+ mName = path.mid( path.tqfindRev( '/' ) + 1 );
TQWidget *wdg = TQWidgetFactory::create( mPath, 0, 0 );
if ( wdg ) {
setText( 0, wdg->caption() );
TQPixmap pm = TQPixmap::grabWidget( wdg );
- TQImage img = pm.convertToImage().smoothScale( 300, 300, TQImage::ScaleMin );
+ TQImage img = pm.convertToImage().smoothScale( 300, 300, TQ_ScaleMin );
mPreview = img;
TQObjectList *list = wdg->queryList( TQWIDGET_OBJECT_NAME_STRING );
@@ -91,7 +91,7 @@ class PageItem : public TQCheckListItem
new TQListViewItem( this, name,
allowedTypes[ it.current()->className() ],
it.current()->className(),
- TQWhatsThis::textFor( static_cast<TQWidget*>( it.current() ) ) );
+ TQWhatsThis::textFor( TQT_TQWIDGET( it.current() ) ) );
}
}
@@ -162,7 +162,7 @@ void KCMDesignerFields::delayedInit()
load();
// Install a dirwatcher that will detect newly created or removed designer files
- KDirWatch *dw = new KDirWatch( this );
+ KDirWatch *dw = new KDirWatch( TQT_TQOBJECT(this) );
KStandardDirs::makeDir(localUiDir());
dw->addDir( localUiDir(), true );
connect( dw, TQT_SIGNAL( created(const TQString&) ), TQT_SLOT( rebuildList() ) );
@@ -176,7 +176,7 @@ void KCMDesignerFields::deleteFile()
if ( item ) {
PageItem *pageItem = static_cast<PageItem*>( item->tqparent() ? item->tqparent() : item );
if (KMessageBox::warningContinueCancel(this,
- i18n( "<qt>Do you really want to delete '<b>%1</b>'?</qt>").arg( pageItem->text(0) ), "", KStdGuiItem::del() )
+ i18n( "<qt>Do you really want to delete '<b>%1</b>'?</qt>").tqarg( pageItem->text(0) ), "", KStdGuiItem::del() )
== KMessageBox::Continue)
KIO::NetAccess::del( pageItem->path(), 0 );
}
@@ -284,7 +284,7 @@ void KCMDesignerFields::initGUI()
mPageView->setFullWidth( true );
hbox->addWidget( mPageView );
- TQGroupBox *box = new TQGroupBox(1, TQt::Horizontal, i18n("Preview of Selected Page"), this );
+ TQGroupBox *box = new TQGroupBox(1, Qt::Horizontal, i18n("Preview of Selected Page"), this );
mPagePreview = new TQLabel( box );
mPagePreview->setMinimumWidth( 300 );
@@ -316,10 +316,10 @@ void KCMDesignerFields::initGUI()
"<p><b>Important:</b> The widget will edit custom fields with an"
" application name of %2. To change the application name"
" to be edited, set the widget name in TQt Designer.</p></qt>" )
- .arg( applicationName(), applicationName() );
+ .tqarg( applicationName(), applicationName() );
KActiveLabel *activeLabel = new KActiveLabel(
- i18n( "<a href=\"whatsthis:%1\">How does this work?</a>" ).arg(cwHowto), this );
+ i18n( "<a href=\"whatsthis:%1\">How does this work?</a>" ).tqarg(cwHowto), this );
hbox->addWidget( activeLabel );
// ### why is this needed? Looks like a KActiveLabel bug...
@@ -360,14 +360,14 @@ void KCMDesignerFields::updatePreview( TQListViewItem *item )
"<tr><td align=\"right\"><b>%5</b></td><td>%6</td></tr>"
"<tr><td align=\"right\"><b>%7</b></td><td>%8</td></tr>"
"</table></qt>" )
- .arg( i18n( "Key:" ) )
- .arg( item->text( 0 ).tqreplace("X_","X-") )
- .arg( i18n( "Type:" ) )
- .arg( item->text( 1 ) )
- .arg( i18n( "Classname:" ) )
- .arg( item->text( 2 ) )
- .arg( i18n( "Description:" ) )
- .arg( item->text( 3 ) );
+ .tqarg( i18n( "Key:" ) )
+ .tqarg( item->text( 0 ).tqreplace("X_","X-") )
+ .tqarg( i18n( "Type:" ) )
+ .tqarg( item->text( 1 ) )
+ .tqarg( i18n( "Classname:" ) )
+ .tqarg( item->text( 2 ) )
+ .tqarg( i18n( "Description:" ) )
+ .tqarg( item->text( 3 ) );
mPageDetails->setText( details );
diff --git a/libkdepim/kdateedit.cpp b/libkdepim/kdateedit.cpp
index 1d54920d..118c92c2 100644
--- a/libkdepim/kdateedit.cpp
+++ b/libkdepim/kdateedit.cpp
@@ -38,7 +38,7 @@ class DateValidator : public TQValidator
{
public:
DateValidator( const TQStringList &keywords, TQWidget* tqparent, const char* name = 0 )
- : TQValidator( tqparent, name ), mKeywords( keywords )
+ : TQValidator( TQT_TQOBJECT(tqparent), name ), mKeywords( keywords )
{}
virtual State validate( TQString &str, int& ) const
@@ -246,7 +246,7 @@ TQDate KDateEdit::parseDate( bool *replaced ) const
bool KDateEdit::eventFilter( TQObject *object, TQEvent *event )
{
- if ( object == lineEdit() ) {
+ if ( TQT_BASE_OBJECT(object) == TQT_BASE_OBJECT(lineEdit()) ) {
// We only process the focus out event if the text has changed
// since we got focus
if ( (event->type() == TQEvent::FocusOut) && mTextChanged ) {
@@ -286,7 +286,7 @@ bool KDateEdit::eventFilter( TQObject *object, TQEvent *event )
case TQEvent::MouseButtonDblClick:
case TQEvent::MouseButtonPress: {
TQMouseEvent *mouseEvent = (TQMouseEvent*)event;
- if ( !mPopup->rect().tqcontains( mouseEvent->pos() ) ) {
+ if ( !TQT_TQRECT_OBJECT(mPopup->rect()).tqcontains( mouseEvent->pos() ) ) {
TQPoint globalPos = mPopup->mapToGlobal( mouseEvent->pos() );
if ( TQApplication::widgetAt( globalPos, true ) == this ) {
// The date picker is being closed by a click on the
@@ -307,7 +307,7 @@ bool KDateEdit::eventFilter( TQObject *object, TQEvent *event )
void KDateEdit::mousePressEvent( TQMouseEvent *event )
{
- if ( event->button() == TQt::LeftButton && mDiscardNextMousePress ) {
+ if ( event->button() == Qt::LeftButton && mDiscardNextMousePress ) {
mDiscardNextMousePress = false;
return;
}
diff --git a/libkdepim/kdepim.widgets b/libkdepim/kdepim.widgets
index 2f1b5e24..a2d69e65 100644
--- a/libkdepim/kdepim.widgets
+++ b/libkdepim/kdepim.widgets
@@ -25,5 +25,5 @@ Group=Input (KDE-PIM)
ToolTip=Time Edit Combobox (KDE-PIM)
WhatsThis=A widget to enter a time. It can also be selected from a drop-down list.
IncludeFile=libkdepim/ktimeedit.h
-ConstructorArgs=(tqparent, QTime::currentTime(), name)
+ConstructorArgs=(parent, TQTime::currentTime(), name)
Group=Input (KDE-PIM)
diff --git a/libkdepim/kfileio.cpp b/libkdepim/kfileio.cpp
index 913ee2cc..01188f00 100644
--- a/libkdepim/kfileio.cpp
+++ b/libkdepim/kfileio.cpp
@@ -48,20 +48,20 @@ KDE_EXPORT TQCString kFileToString(const TQString &aFileName, bool aEnsureNL, bo
if (!info.exists())
{
if (aVerbose)
- msgDialog(i18n("The specified file does not exist:\n%1").arg(aFileName));
+ msgDialog(i18n("The specified file does not exist:\n%1").tqarg(aFileName));
return TQCString();
}
if (info.isDir())
{
if (aVerbose)
- msgDialog(i18n("This is a folder and not a file:\n%1").arg(aFileName));
+ msgDialog(i18n("This is a folder and not a file:\n%1").tqarg(aFileName));
return TQCString();
}
if (!info.isReadable())
{
if (aVerbose)
msgDialog(i18n("You do not have read permissions "
- "to the file:\n%1").arg(aFileName));
+ "to the file:\n%1").tqarg(aFileName));
return TQCString();
}
if (len <= 0) return TQCString();
@@ -71,13 +71,13 @@ KDE_EXPORT TQCString kFileToString(const TQString &aFileName, bool aEnsureNL, bo
if (aVerbose) switch(file.status())
{
case IO_ReadError:
- msgDialog(i18n("Could not read file:\n%1").arg(aFileName));
+ msgDialog(i18n("Could not read file:\n%1").tqarg(aFileName));
break;
case IO_OpenError:
- msgDialog(i18n("Could not open file:\n%1").arg(aFileName));
+ msgDialog(i18n("Could not open file:\n%1").tqarg(aFileName));
break;
default:
- msgDialog(i18n("Error while reading file:\n%1").arg(aFileName));
+ msgDialog(i18n("Error while reading file:\n%1").tqarg(aFileName));
}
return TQCString();
}
@@ -94,7 +94,7 @@ KDE_EXPORT TQCString kFileToString(const TQString &aFileName, bool aEnsureNL, bo
if (readLen < len)
{
TQString msg = i18n("Could only read %1 bytes of %2.")
- .arg(readLen).arg(len);
+ .tqarg(readLen).tqarg(len);
msgDialog(msg);
return TQCString();
}
@@ -120,21 +120,21 @@ TQByteArray kFileToBytes(const TQString &aFileName, bool aVerbose)
{
if (aVerbose)
msgDialog(i18n("The specified file does not exist:\n%1")
- .arg(aFileName));
+ .tqarg(aFileName));
return result;
}
if (info.isDir())
{
if (aVerbose)
msgDialog(i18n("This is a folder and not a file:\n%1")
- .arg(aFileName));
+ .tqarg(aFileName));
return result;
}
if (!info.isReadable())
{
if (aVerbose)
msgDialog(i18n("You do not have read permissions "
- "to the file:\n%1").arg(aFileName));
+ "to the file:\n%1").tqarg(aFileName));
return result;
}
if (len <= 0) return result;
@@ -144,26 +144,26 @@ TQByteArray kFileToBytes(const TQString &aFileName, bool aVerbose)
if (aVerbose) switch(file.status())
{
case IO_ReadError:
- msgDialog(i18n("Could not read file:\n%1").arg(aFileName));
+ msgDialog(i18n("Could not read file:\n%1").tqarg(aFileName));
break;
case IO_OpenError:
- msgDialog(i18n("Could not open file:\n%1").arg(aFileName));
+ msgDialog(i18n("Could not open file:\n%1").tqarg(aFileName));
break;
default:
- msgDialog(i18n("Error while reading file:\n%1").arg(aFileName));
+ msgDialog(i18n("Error while reading file:\n%1").tqarg(aFileName));
}
return result;
}
result.resize(len);
readLen = file.readBlock(result.data(), len);
- kdDebug(5300) << TQString( "len %1" ).arg(len) << endl;
+ kdDebug(5300) << TQString( "len %1" ).tqarg(len) << endl;
if (readLen < len)
{
TQString msg;
msg = i18n("Could only read %1 bytes of %2.")
- .arg(readLen).arg(len);
+ .tqarg(readLen).tqarg(len);
msgDialog(msg);
return result;
}
@@ -191,7 +191,7 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
{
TQString str;
str = i18n("File %1 exists.\nDo you want to replace it?")
- .arg(aFileName);
+ .tqarg(aFileName);
rc = KMessageBox::warningContinueCancel(0,
str, i18n("Save to File"), i18n("&Replace"));
if (rc != KMessageBox::Continue) return FALSE;
@@ -209,7 +209,7 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
if (!aVerbose) return FALSE;
rc = KMessageBox::warningContinueCancel(0,
i18n("Failed to make a backup copy of %1.\nContinue anyway?")
- .arg(aFileName),
+ .tqarg(aFileName),
i18n("Save to File"), KStdGuiItem::save() );
if (rc != KMessageBox::Continue) return FALSE;
}
@@ -221,14 +221,14 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
if (aVerbose) switch(file.status())
{
case IO_WriteError:
- msgDialog(i18n("Could not write to file:\n%1").arg(aFileName));
+ msgDialog(i18n("Could not write to file:\n%1").tqarg(aFileName));
break;
case IO_OpenError:
msgDialog(i18n("Could not open file for writing:\n%1")
- .arg(aFileName));
+ .tqarg(aFileName));
break;
default:
- msgDialog(i18n("Error while writing file:\n%1").arg(aFileName));
+ msgDialog(i18n("Error while writing file:\n%1").tqarg(aFileName));
}
return FALSE;
}
@@ -238,13 +238,13 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
if (writeLen < 0)
{
if (aVerbose)
- msgDialog(i18n("Could not write to file:\n%1").arg(aFileName));
+ msgDialog(i18n("Could not write to file:\n%1").tqarg(aFileName));
return FALSE;
}
else if (writeLen < len)
{
TQString msg = i18n("Could only write %1 bytes of %2.")
- .arg(writeLen).arg(len);
+ .tqarg(writeLen).tqarg(len);
if (aVerbose)
msgDialog(msg);
return FALSE;
@@ -283,7 +283,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
if ( !fiToCheck.exists() ) {
error.append( i18n("%1 does not exist")
- .arg(toCheck) + "\n");
+ .tqarg(toCheck) + "\n");
}
// check the access bit of a folder.
@@ -295,7 +295,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
if ( !g.isReadable() ) {
if ( chmod( toCheckEnc, statbuffer.st_mode + S_IXUSR ) != 0 ) {
error.append( i18n("%1 is not accessible and that is "
- "unchangeable.").arg(toCheck) + "\n");
+ "unchangeable.").tqarg(toCheck) + "\n");
} else {
kdDebug() << "Changed access bit for " << toCheck << endl;
}
@@ -316,7 +316,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
// Lets try changing it.
if ( chmod( toCheckEnc, statbuffer.st_mode + S_IRUSR ) != 0 ) {
error.append( i18n("%1 is not readable and that is unchangeable.")
- .arg(toCheck) + "\n");
+ .tqarg(toCheck) + "\n");
} else {
kdDebug() << "Changed the read bit for " << toCheck << endl;
}
@@ -332,7 +332,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
// Lets try changing it.
if ( chmod (toCheckEnc, statbuffer.st_mode + S_IWUSR ) != 0 ) {
error.append( i18n("%1 is not writable and that is unchangeable.")
- .arg(toCheck) + "\n");
+ .tqarg(toCheck) + "\n");
} else {
kdDebug() << "Changed the write bit for " << toCheck << endl;
}
@@ -346,7 +346,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
// First check if the folder is readable for us. If not, we get
// some ugly crashes.
if ( !g.isReadable() ){
- error.append(i18n("Folder %1 is inaccessible.").arg(toCheck) + "\n");
+ error.append(i18n("Folder %1 is inaccessible.").tqarg(toCheck) + "\n");
} else {
const TQFileInfoList *list = g.entryInfoList();
TQFileInfoListIterator it( *list );
diff --git a/libkdepim/kfoldertree.cpp b/libkdepim/kfoldertree.cpp
index 0098adbb..48398ddc 100644
--- a/libkdepim/kfoldertree.cpp
+++ b/libkdepim/kfoldertree.cpp
@@ -198,7 +198,7 @@ void KFolderTreeItem::setFolderSize( TQ_INT64 aSize )
TQ_INT64 recursiveSize = recursiveFolderSize();
if ( recursiveSize != mSize ) {
if ( mType != Root )
- size += TQString::tqfromLatin1(" + %1").arg( KIO::convertSize( recursiveSize - mSize ) );
+ size += TQString::tqfromLatin1(" + %1").tqarg( KIO::convertSize( recursiveSize - mSize ) );
else
size = KIO::convertSize( recursiveSize );
}
@@ -390,10 +390,10 @@ void KFolderTree::setStyleDependantFrameWidth()
{
// set the width of the frame to a reasonable value for the current GUI style
int frameWidth;
- if( style().isA("KeramikStyle") )
- frameWidth = style().tqpixelMetric( TQStyle::PM_DefaultFrameWidth ) - 1;
+ if( tqstyle().isA("KeramikStyle") )
+ frameWidth = tqstyle().tqpixelMetric( TQStyle::PM_DefaultFrameWidth ) - 1;
else
- frameWidth = style().tqpixelMetric( TQStyle::PM_DefaultFrameWidth );
+ frameWidth = tqstyle().tqpixelMetric( TQStyle::PM_DefaultFrameWidth );
if ( frameWidth < 0 )
frameWidth = 0;
if ( frameWidth != lineWidth() )
diff --git a/libkdepim/kincidencechooser.cpp b/libkdepim/kincidencechooser.cpp
index 431d650d..b9d8758e 100644
--- a/libkdepim/kincidencechooser.cpp
+++ b/libkdepim/kincidencechooser.cpp
@@ -104,7 +104,7 @@ KIncidenceChooser::KIncidenceChooser(TQWidget *tqparent, char *name) :
#else
mDiffBut = 0;
#endif
- mBg = new TQButtonGroup ( 1, TQt::Horizontal, i18n("Sync Preferences"), topFrame);
+ mBg = new TQButtonGroup ( 1, Qt::Horizontal, i18n("Sync Preferences"), topFrame);
topLayout->addMultiCellWidget(mBg, iii,iii,0,2);
++iii;
mBg->insert( new TQRadioButton ( i18n("Take local entry on conflict"), mBg ), KIncidenceChooser::local);
@@ -249,7 +249,7 @@ void KIncidenceChooser::showIncidence1()
void KIncidenceChooser::detailsDialogClosed()
{
- KDialogBase* dialog = static_cast<KDialogBase *>( const_cast<TQObject *>( sender() ) );
+ KDialogBase* dialog = static_cast<KDialogBase *>( const_cast<TQWidget *>( TQT_TQWIDGET(sender()) ) );
if ( dialog == mTbL )
mShowDetails1->setText( i18n( "Show details..." ) );
else
@@ -265,9 +265,9 @@ void KIncidenceChooser::showDiff()
}
mDisplayDiff = new KPIM::HTMLDiffAlgoDisplay (this);
if ( mInc1->summary().left( 20 ) != mInc2->summary().left( 20 ) )
- mDisplayDiff->setCaption( i18n( "Differences of %1 and %2").arg( mInc1->summary().left( 20 ) ).arg( mInc2->summary().left( 20 ) ) );
+ mDisplayDiff->setCaption( i18n( "Differences of %1 and %2").tqarg( mInc1->summary().left( 20 ) ).tqarg( mInc2->summary().left( 20 ) ) );
else
- mDisplayDiff->setCaption( i18n( "Differences of %1").arg( mInc1->summary().left( 20 ) ) );
+ mDisplayDiff->setCaption( i18n( "Differences of %1").tqarg( mInc1->summary().left( 20 ) ) );
diff = new KPIM::CalendarDiffAlgo( mInc1, mInc2);
diff->setLeftSourceTitle( i18n( "Local entry"));
diff --git a/libkdepim/komposer/core/pluginmanager.cpp b/libkdepim/komposer/core/pluginmanager.cpp
index d46d471b..50ef26a9 100644
--- a/libkdepim/komposer/core/pluginmanager.cpp
+++ b/libkdepim/komposer/core/pluginmanager.cpp
@@ -311,7 +311,7 @@ PluginManager::loadPluginInternal( const TQString &pluginId )
int error = 0;
Plugin *plugin = KParts::ComponentFactory::createInstanceFromQuery<Komposer::Plugin>(
TQString::tqfromLatin1( "Komposer/Plugin" ),
- TQString::tqfromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).arg( pluginId ),
+ TQString::tqfromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).tqarg( pluginId ),
this, 0, TQStringList(), &error );
if ( plugin ) {
diff --git a/libkdepim/komposer/plugins/default/defaulteditor.cpp b/libkdepim/komposer/plugins/default/defaulteditor.cpp
index 6f7dcb7d..c75f6392 100644
--- a/libkdepim/komposer/plugins/default/defaulteditor.cpp
+++ b/libkdepim/komposer/plugins/default/defaulteditor.cpp
@@ -86,8 +86,8 @@ DefaultEditor::changeSignature( const TQString &sig )
{
TQString text = m_textEdit->text();
- int sigStart = text.findRev( "-- " );
- TQString sigText = TQString( "-- \n%1" ).arg( sig );
+ int sigStart = text.tqfindRev( "-- " );
+ TQString sigText = TQString( "-- \n%1" ).tqarg( sig );
text.tqreplace( sigStart, text.length(), sigText );
}
diff --git a/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp b/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
index b25e5035..11016890 100644
--- a/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
+++ b/libkdepim/kpartsdesignerplugin/kpartsdesignerplugin.cpp
@@ -48,7 +48,7 @@ void KPartsGenericPart::load()
delete m_part;
}
// "this" is both the tqparent widget and the tqparent object
- m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), this, 0, this, 0 );
+ m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString(), TQT_TQWIDGET(this), 0, TQT_TQOBJECT(this), 0 );
if ( m_part ) {
m_part->openURL( m_url );
m_part->widget()->show();
diff --git a/libkdepim/kpixmapregionselectorwidget.cpp b/libkdepim/kpixmapregionselectorwidget.cpp
index 4efcbbcb..a6d992f5 100644
--- a/libkdepim/kpixmapregionselectorwidget.cpp
+++ b/libkdepim/kpixmapregionselectorwidget.cpp
@@ -144,13 +144,13 @@ KPopupMenu *KPixmapRegionSelectorWidget::createPopupMenu()
popup->insertTitle(i18n("Image Operations"));
KAction *action = new KAction(i18n("&Rotate Clockwise"), "rotate_cw",
- 0, this, TQT_SLOT(rotateClockwise()),
- popup, "rotateclockwise");
+ 0, TQT_TQOBJECT(this), TQT_SLOT(rotateClockwise()),
+ TQT_TQOBJECT(popup), "rotateclockwise");
action->plug(popup);
action = new KAction(i18n("Rotate &Counterclockwise"), "rotate_ccw",
- 0, this, TQT_SLOT(rotateCounterclockwise()),
- popup, "rotatecounterclockwise");
+ 0, TQT_TQOBJECT(this), TQT_SLOT(rotateCounterclockwise()),
+ TQT_TQOBJECT(popup), "rotatecounterclockwise");
action->plug(popup);
/*
@@ -216,9 +216,9 @@ bool KPixmapRegionSelectorWidget::eventFilter(TQObject *obj, TQEvent *ev)
if ( ev->type() == TQEvent::MouseButtonPress )
{
TQMouseEvent *mev= (TQMouseEvent *)(ev);
- //kdDebug() << TQString("click at %1,%2").arg( mev->x() ).arg( mev->y() ) << endl;
+ //kdDebug() << TQString("click at %1,%2").tqarg( mev->x() ).tqarg( mev->y() ) << endl;
- if ( mev->button() == RightButton )
+ if ( mev->button() == Qt::RightButton )
{
KPopupMenu *popup = createPopupMenu( );
popup->exec( mev->globalPos() );
@@ -249,7 +249,7 @@ bool KPixmapRegionSelectorWidget::eventFilter(TQObject *obj, TQEvent *ev)
{
TQMouseEvent *mev= (TQMouseEvent *)(ev);
- //kdDebug() << TQString("move to %1,%2").arg( mev->x() ).arg( mev->y() ) << endl;
+ //kdDebug() << TQString("move to %1,%2").tqarg( mev->x() ).tqarg( mev->y() ) << endl;
if ( m_state == Resizing )
{
@@ -421,7 +421,7 @@ void KPixmapRegionSelectorWidget::setMaximumWidgetSize(int width, int height)
if (m_selectedRegion == m_originalPixmap.rect()) m_selectedRegion=TQRect();
// kdDebug() << TQString(" original Pixmap :") << m_originalPixmap.rect() << endl;
-// kdDebug() << TQString(" unzoomed Pixmap : %1 x %2 ").arg(m_unzoomedPixmap.width()).arg(m_unzoomedPixmap.height()) << endl;
+// kdDebug() << TQString(" unzoomed Pixmap : %1 x %2 ").tqarg(m_unzoomedPixmap.width()).tqarg(m_unzoomedPixmap.height()) << endl;
if ( !m_originalPixmap.isNull() &&
( m_originalPixmap.width() > m_maxWidth ||
@@ -429,7 +429,7 @@ void KPixmapRegionSelectorWidget::setMaximumWidgetSize(int width, int height)
{
/* We have to resize the pixmap to get it complete on the screen */
TQImage image=m_originalPixmap.convertToImage();
- m_originalPixmap.convertFromImage( image.smoothScale( width, height, TQImage::ScaleMin ) );
+ m_originalPixmap.convertFromImage( image.smoothScale( width, height, TQ_ScaleMin ) );
//m_originalPixmap.convertFromImage( KImageEffect::sample( image, width, height ) );
double oldZoomFactor = m_zoomFactor;
m_zoomFactor=m_originalPixmap.width()/(double)m_unzoomedPixmap.width();
diff --git a/libkdepim/kprefsdialog.cpp b/libkdepim/kprefsdialog.cpp
index 547c712c..bb2bdca7 100644
--- a/libkdepim/kprefsdialog.cpp
+++ b/libkdepim/kprefsdialog.cpp
@@ -401,7 +401,7 @@ KPrefsWidRadios::KPrefsWidRadios( KConfigSkeleton::ItemEnum *item,
TQWidget *tqparent )
: mItem( item )
{
- mBox = new TQButtonGroup( 1, TQt::Horizontal, mItem->label(), tqparent );
+ mBox = new TQButtonGroup( 1, Qt::Horizontal, mItem->label(), tqparent );
connect( mBox, TQT_SIGNAL( clicked( int ) ), TQT_SIGNAL( changed() ) );
}
diff --git a/libkdepim/kregexp3.cpp b/libkdepim/kregexp3.cpp
index 87827e07..ca9725ba 100644
--- a/libkdepim/kregexp3.cpp
+++ b/libkdepim/kregexp3.cpp
@@ -64,7 +64,7 @@ TQString KRegExp3::tqreplace( const TQString & str,
pos = rx.search( replacementStr, pos );
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Found match at pos %1").arg(pos) << endl;
+ kdDebug() << TQString(" Found match at pos %1").tqarg(pos) << endl;
#endif
if ( pos < 0 ) {
@@ -88,13 +88,13 @@ TQString KRegExp3::tqreplace( const TQString & str,
backRefs << rx.cap(i).toInt();
#ifdef DEBUG_KREGEXP3
kdDebug() << TQString(" Found %1 at position %2 in the capturedTexts.")
- .arg(backRefs.last()).arg(i) << endl;
+ .tqarg(backRefs.last()).tqarg(i) << endl;
#endif
break;
}
pos += rx.matchedLength();
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Setting new pos to %1.").arg(pos) << endl;
+ kdDebug() << TQString(" Setting new pos to %1.").tqarg(pos) << endl;
#endif
oldpos = pos;
}
@@ -125,7 +125,7 @@ TQString KRegExp3::tqreplace( const TQString & str,
pos = search( str, pos );
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Found match at pos %1").arg(pos) << endl;
+ kdDebug() << TQString(" Found match at pos %1").tqarg(pos) << endl;
#endif
if ( pos < 0 ) {
@@ -168,7 +168,7 @@ TQString KRegExp3::tqreplace( const TQString & str,
}
pos += matchedLength();
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Setting new pos to %1.").arg(pos) << endl;
+ kdDebug() << TQString(" Setting new pos to %1.").tqarg(pos) << endl;
#endif
oldpos = pos;
diff --git a/libkdepim/kscoring.cpp b/libkdepim/kscoring.cpp
index 8c5f737e..58595b93 100644
--- a/libkdepim/kscoring.cpp
+++ b/libkdepim/kscoring.cpp
@@ -936,7 +936,7 @@ KScoringRule* KScoringManager::addRule(const ScorableArticle& a, TQString group,
KScoringRule* KScoringManager::addRule(KScoringRule* expr)
{
- int i = allRules.findRef(expr);
+ int i = allRules.tqfindRef(expr);
if (i == -1) {
// only add a rule we don't know
addRuleInternal(expr);
@@ -965,7 +965,7 @@ void KScoringManager::addRuleInternal(KScoringRule *e)
void KScoringManager::cancelNewRule(KScoringRule *r)
{
// if e was'nt previously added to the list of rules, we delete it
- int i = allRules.findRef(r);
+ int i = allRules.tqfindRef(r);
if (i == -1) {
kdDebug(5100) << "deleting rule " << r->getName() << endl;
deleteRule(r);
@@ -1002,7 +1002,7 @@ void KScoringManager::setRuleName(KScoringRule *r, const TQString& s)
void KScoringManager::deleteRule(KScoringRule *r)
{
- int i = allRules.findRef(r);
+ int i = allRules.tqfindRef(r);
if (i != -1) {
allRules.remove();
emit changedRules();
@@ -1019,8 +1019,8 @@ void KScoringManager::editRule(KScoringRule *e, TQWidget *w)
void KScoringManager::moveRuleAbove( KScoringRule *above, KScoringRule *below )
{
- int aindex = allRules.findRef( above );
- int bindex = allRules.findRef( below );
+ int aindex = allRules.tqfindRef( above );
+ int bindex = allRules.tqfindRef( below );
if ( aindex <= 0 || bindex < 0 )
return;
if ( aindex < bindex )
@@ -1031,8 +1031,8 @@ void KScoringManager::moveRuleAbove( KScoringRule *above, KScoringRule *below )
void KScoringManager::moveRuleBelow( KScoringRule *below, KScoringRule *above )
{
- int bindex = allRules.findRef( below );
- int aindex = allRules.findRef( above );
+ int bindex = allRules.tqfindRef( below );
+ int aindex = allRules.tqfindRef( above );
if ( bindex < 0 || bindex >= (int)allRules.count() - 1 || aindex < 0 )
return;
if ( bindex < aindex )
@@ -1137,7 +1137,7 @@ TQString KScoringManager::findUniqueName() const
while (nr < 99999999) {
nr++;
- ret = i18n("rule %1").arg(nr);
+ ret = i18n("rule %1").tqarg(nr);
duplicated=false;
TQPtrListIterator<KScoringRule> it(allRules);
diff --git a/libkdepim/kscoringeditor.cpp b/libkdepim/kscoringeditor.cpp
index 7cec1a7d..0c1a4294 100644
--- a/libkdepim/kscoringeditor.cpp
+++ b/libkdepim/kscoringeditor.cpp
@@ -301,7 +301,7 @@ ActionBase* SingleActionWidget::createAction() const
case ActionBase::NOTIFY:
return new ActionNotify(notifyEditor->text());
case ActionBase::COLOR:
- return new ActionColor(colorEditor->color().name());
+ return new ActionColor(TQString(colorEditor->color().name()));
case ActionBase::MARKASREAD:
return new ActionMarkAsRead();
default:
diff --git a/libkdepim/ksubscription.cpp b/libkdepim/ksubscription.cpp
index cff384f2..a17ae841 100644
--- a/libkdepim/ksubscription.cpp
+++ b/libkdepim/ksubscription.cpp
@@ -775,7 +775,7 @@ void KSubscription::slotUpdateStatusLabel()
activeItemCount());
else
text = i18n("%1: (1 matching)", "%1: (%n matching)", activeItemCount())
- .arg(account()->name());
+ .tqarg(account()->name());
leftLabel->setText(text);
}
diff --git a/libkdepim/ktimeedit.cpp b/libkdepim/ktimeedit.cpp
index 7512b89e..c313009c 100644
--- a/libkdepim/ktimeedit.cpp
+++ b/libkdepim/ktimeedit.cpp
@@ -43,7 +43,7 @@
class KOTimeValidator : public TQValidator
{
public:
- KOTimeValidator(TQWidget* tqparent, const char* name=0) : TQValidator(tqparent, name) {}
+ KOTimeValidator(TQWidget* tqparent, const char* name=0) : TQValidator(TQT_TQOBJECT(tqparent), name) {}
virtual State validate(TQString& str, int& /*cursorPos*/) const
{
@@ -126,7 +126,7 @@ KTimeEdit::KTimeEdit( TQWidget *tqparent, TQTime qt, const char *name )
insertItem( KGlobal::locale()->formatTime( TQTime( 23, 59, 59 ) ) );
updateText();
- setFocusPolicy(TQWidget::StrongFocus);
+ setFocusPolicy(Qt::StrongFocus);
connect(this, TQT_SIGNAL(activated(int)), this, TQT_SLOT(active(int)));
connect(this, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(hilit(int)));
@@ -178,7 +178,7 @@ void KTimeEdit::setTime(TQTime newTime)
{
if ( mTime != newTime )
{
- kdDebug(5300) << "KTimeEdit::setTime(): " << newTime.toString() << endl;
+ kdDebug(5300) << "KTimeEdit::setTime(): " << TQString(newTime.toString()) << endl;
mTime = newTime;
updateText();
diff --git a/libkdepim/kwidgetlister.cpp b/libkdepim/kwidgetlister.cpp
index bc9d8980..98c6062b 100644
--- a/libkdepim/kwidgetlister.cpp
+++ b/libkdepim/kwidgetlister.cpp
@@ -125,7 +125,7 @@ void KWidgetLister::addWidgetAtEnd(TQWidget *w)
{
if (!w) w = this->createWidget(this);
- mLayout->insertWidget( mLayout->findWidget( mButtonBox ), w );
+ mLayout->insertWidget( mLayout->tqfindWidget( mButtonBox ), w );
mWidgetList.append( w );
w->show();
enableControls();
diff --git a/libkdepim/ldapclient.cpp b/libkdepim/ldapclient.cpp
index 651c8615..2f29b763 100644
--- a/libkdepim/ldapclient.cpp
+++ b/libkdepim/ldapclient.cpp
@@ -49,7 +49,7 @@ static KStaticDeleter<KConfig> configDeleter;
TQString LdapObject::toString() const
{
- TQString result = TQString::tqfromLatin1( "\ndn: %1\n" ).arg( dn );
+ TQString result = TQString::tqfromLatin1( "\ndn: %1\n" ).tqarg( dn );
for ( LdapAttrMap::ConstIterator it = attrs.begin(); it != attrs.end(); ++it ) {
TQString attr = it.key();
for ( LdapAttrValue::ConstIterator it2 = (*it).begin(); it2 != (*it).end(); ++it2 ) {
@@ -278,53 +278,53 @@ void LdapSearch::readConfig( LdapServer &server, KConfig *config, int j, bool ac
{
TQString prefix;
if ( active ) prefix = "Selected";
- TQString host = config->readEntry( prefix + TQString( "Host%1" ).arg( j ), "" ).stripWhiteSpace();
+ TQString host = config->readEntry( prefix + TQString( "Host%1" ).tqarg( j ), "" ).stripWhiteSpace();
if ( !host.isEmpty() )
server.setHost( host );
- int port = config->readNumEntry( prefix + TQString( "Port%1" ).arg( j ), 389 );
+ int port = config->readNumEntry( prefix + TQString( "Port%1" ).tqarg( j ), 389 );
server.setPort( port );
- TQString base = config->readEntry( prefix + TQString( "Base%1" ).arg( j ), "" ).stripWhiteSpace();
+ TQString base = config->readEntry( prefix + TQString( "Base%1" ).tqarg( j ), "" ).stripWhiteSpace();
if ( !base.isEmpty() )
server.setBaseDN( base );
- TQString user = config->readEntry( prefix + TQString( "User%1" ).arg( j ) ).stripWhiteSpace();
+ TQString user = config->readEntry( prefix + TQString( "User%1" ).tqarg( j ) ).stripWhiteSpace();
if ( !user.isEmpty() )
server.setUser( user );
- TQString bindDN = config->readEntry( prefix + TQString( "Bind%1" ).arg( j ) ).stripWhiteSpace();
+ TQString bindDN = config->readEntry( prefix + TQString( "Bind%1" ).tqarg( j ) ).stripWhiteSpace();
if ( !bindDN.isEmpty() )
server.setBindDN( bindDN );
- TQString pwdBindDN = config->readEntry( prefix + TQString( "PwdBind%1" ).arg( j ) );
+ TQString pwdBindDN = config->readEntry( prefix + TQString( "PwdBind%1" ).tqarg( j ) );
if ( !pwdBindDN.isEmpty() )
server.setPwdBindDN( pwdBindDN );
- server.setTimeLimit( config->readNumEntry( prefix + TQString( "TimeLimit%1" ).arg( j ) ) );
- server.setSizeLimit( config->readNumEntry( prefix + TQString( "SizeLimit%1" ).arg( j ) ) );
- server.setVersion( config->readNumEntry( prefix + TQString( "Version%1" ).arg( j ), 3 ) );
- server.setSecurity( config->readNumEntry( prefix + TQString( "Security%1" ).arg( j ) ) );
- server.setAuth( config->readNumEntry( prefix + TQString( "Auth%1" ).arg( j ) ) );
- server.setMech( config->readEntry( prefix + TQString( "Mech%1" ).arg( j ) ) );
+ server.setTimeLimit( config->readNumEntry( prefix + TQString( "TimeLimit%1" ).tqarg( j ) ) );
+ server.setSizeLimit( config->readNumEntry( prefix + TQString( "SizeLimit%1" ).tqarg( j ) ) );
+ server.setVersion( config->readNumEntry( prefix + TQString( "Version%1" ).tqarg( j ), 3 ) );
+ server.setSecurity( config->readNumEntry( prefix + TQString( "Security%1" ).tqarg( j ) ) );
+ server.setAuth( config->readNumEntry( prefix + TQString( "Auth%1" ).tqarg( j ) ) );
+ server.setMech( config->readEntry( prefix + TQString( "Mech%1" ).tqarg( j ) ) );
}
void LdapSearch::writeConfig( const LdapServer &server, KConfig *config, int j, bool active )
{
TQString prefix;
if ( active ) prefix = "Selected";
- config->writeEntry( prefix + TQString( "Host%1" ).arg( j ), server.host() );
- config->writeEntry( prefix + TQString( "Port%1" ).arg( j ), server.port() );
- config->writeEntry( prefix + TQString( "Base%1" ).arg( j ), server.baseDN() );
- config->writeEntry( prefix + TQString( "User%1" ).arg( j ), server.user() );
- config->writeEntry( prefix + TQString( "Bind%1" ).arg( j ), server.bindDN() );
- config->writeEntry( prefix + TQString( "PwdBind%1" ).arg( j ), server.pwdBindDN() );
- config->writeEntry( prefix + TQString( "TimeLimit%1" ).arg( j ), server.timeLimit() );
- config->writeEntry( prefix + TQString( "SizeLimit%1" ).arg( j ), server.sizeLimit() );
- config->writeEntry( prefix + TQString( "Version%1" ).arg( j ), server.version() );
- config->writeEntry( prefix + TQString( "Security%1" ).arg( j ), server.security() );
- config->writeEntry( prefix + TQString( "Auth%1" ).arg( j ), server.auth() );
- config->writeEntry( prefix + TQString( "Mech%1" ).arg( j ), server.mech() );
+ config->writeEntry( prefix + TQString( "Host%1" ).tqarg( j ), server.host() );
+ config->writeEntry( prefix + TQString( "Port%1" ).tqarg( j ), server.port() );
+ config->writeEntry( prefix + TQString( "Base%1" ).tqarg( j ), server.baseDN() );
+ config->writeEntry( prefix + TQString( "User%1" ).tqarg( j ), server.user() );
+ config->writeEntry( prefix + TQString( "Bind%1" ).tqarg( j ), server.bindDN() );
+ config->writeEntry( prefix + TQString( "PwdBind%1" ).tqarg( j ), server.pwdBindDN() );
+ config->writeEntry( prefix + TQString( "TimeLimit%1" ).tqarg( j ), server.timeLimit() );
+ config->writeEntry( prefix + TQString( "SizeLimit%1" ).tqarg( j ), server.sizeLimit() );
+ config->writeEntry( prefix + TQString( "Version%1" ).tqarg( j ), server.version() );
+ config->writeEntry( prefix + TQString( "Security%1" ).tqarg( j ), server.security() );
+ config->writeEntry( prefix + TQString( "Auth%1" ).tqarg( j ), server.auth() );
+ config->writeEntry( prefix + TQString( "Mech%1" ).tqarg( j ), server.mech() );
}
KConfig* LdapSearch::config()
@@ -351,7 +351,7 @@ LdapSearch::LdapSearch()
void LdapSearch::readWeighForClient( LdapClient *client, KConfig *config, int clientNumber )
{
- const int completionWeight = config->readNumEntry( TQString( "SelectedCompletionWeight%1" ).arg( clientNumber ), -1 );
+ const int completionWeight = config->readNumEntry( TQString( "SelectedCompletionWeight%1" ).tqarg( clientNumber ), -1 );
if ( completionWeight != -1 )
client->setCompletionWeight( completionWeight );
}
@@ -442,7 +442,7 @@ void LdapSearch::startSearch( const TQString& txt )
* person entries without an email address to show up, while still not showing things
* like structural entries in the ldap tree. */
TQString filter = TQString( "&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))(|(cn=%1*)(mail=%2*)(mail=*@%3*)(givenName=%4*)(sn=%5*))" )
- .arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText );
+ .tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText );
TQValueList< LdapClient* >::Iterator it;
for ( it = mClients.begin(); it != mClients.end(); ++it ) {
@@ -590,7 +590,7 @@ void LdapSearch::makeSearchData( TQStringList& ret, LdapResultList& resList )
ret.append( mail );
} else {
//kdDebug(5300) << "LdapSearch::makeSearchData() name: \"" << name << "\" mail: \"" << mail << "\"" << endl;
- ret.append( TQString( "%1 <%2>" ).arg( name ).arg( mail ) );
+ ret.append( TQString( "%1 <%2>" ).tqarg( name ).tqarg( mail ) );
}
LdapResult sr;
diff --git a/libkdepim/ldapsearchdialog.cpp b/libkdepim/ldapsearchdialog.cpp
index 2297e17e..36c7517b 100644
--- a/libkdepim/ldapsearchdialog.cpp
+++ b/libkdepim/ldapsearchdialog.cpp
@@ -136,7 +136,7 @@ LDAPSearchDialog::LDAPSearchDialog( TQWidget* tqparent, const char* name )
page );
groupBox->setFrameShape( TQGroupBox::Box );
groupBox->setFrameShadow( TQGroupBox::Sunken );
- groupBox->setColumnLayout( 0, TQt::Vertical );
+ groupBox->setColumnLayout( 0, Qt::Vertical );
TQGridLayout *boxLayout = new TQGridLayout( groupBox->tqlayout(), 2,
5, spacingHint() );
boxLayout->setColStretch( 1, 1 );
@@ -238,27 +238,27 @@ void LDAPSearchDialog::restoreSettings()
for ( int j = 0; j < mNumHosts; ++j ) {
KPIM::LdapServer ldapServer;
- TQString host = config->readEntry( TQString( "SelectedHost%1" ).arg( j ), "" );
+ TQString host = config->readEntry( TQString( "SelectedHost%1" ).tqarg( j ), "" );
if ( !host.isEmpty() )
ldapServer.setHost( host );
- int port = config->readUnsignedNumEntry( TQString( "SelectedPort%1" ).arg( j ) );
+ int port = config->readUnsignedNumEntry( TQString( "SelectedPort%1" ).tqarg( j ) );
if ( port )
ldapServer.setPort( port );
- TQString base = config->readEntry( TQString( "SelectedBase%1" ).arg( j ), "" );
+ TQString base = config->readEntry( TQString( "SelectedBase%1" ).tqarg( j ), "" );
if ( !base.isEmpty() )
ldapServer.setBaseDN( base );
- TQString bindDN = config->readEntry( TQString( "SelectedBind%1" ).arg( j ), "" );
+ TQString bindDN = config->readEntry( TQString( "SelectedBind%1" ).tqarg( j ), "" );
if ( !bindDN.isEmpty() )
ldapServer.setBindDN( bindDN );
- TQString pwdBindDN = config->readEntry( TQString( "SelectedPwdBind%1" ).arg( j ), "" );
+ TQString pwdBindDN = config->readEntry( TQString( "SelectedPwdBind%1" ).tqarg( j ), "" );
if ( !pwdBindDN.isEmpty() )
ldapServer.setPwdBindDN( pwdBindDN );
- KPIM::LdapClient* ldapClient = new KPIM::LdapClient( 0, this, "ldapclient" );
+ KPIM::LdapClient* ldapClient = new KPIM::LdapClient( 0, TQT_TQOBJECT(this), "ldapclient" );
ldapClient->setServer( ldapServer );
TQStringList attrs;
@@ -352,15 +352,15 @@ TQString LDAPSearchDialog::makeFilter( const TQString& query, const TQString& at
if ( attr == i18n( "Name" ) ) {
result += startsWith ? "|(cn=%1*)(sn=%2*)" : "|(cn=*%1*)(sn=*%2*)";
- result = result.arg( query ).arg( query );
+ result = result.tqarg( query ).tqarg( query );
} else {
result += (startsWith ? "%1=%2*" : "%1=*%2*");
if ( attr == i18n( "Email" ) ) {
- result = result.arg( "mail" ).arg( query );
+ result = result.tqarg( "mail" ).tqarg( query );
} else if ( attr == i18n( "Home Number" ) ) {
- result = result.arg( "homePhone" ).arg( query );
+ result = result.tqarg( "homePhone" ).tqarg( query );
} else if ( attr == i18n( "Work Number" ) ) {
- result = result.arg( "telephoneNumber" ).arg( query );
+ result = result.tqarg( "telephoneNumber" ).tqarg( query );
} else {
// Error?
result = TQString();
diff --git a/libkdepim/linklocator.cpp b/libkdepim/linklocator.cpp
index 6a79dff1..e0c4c0d2 100644
--- a/libkdepim/linklocator.cpp
+++ b/libkdepim/linklocator.cpp
@@ -362,7 +362,7 @@ TQString LinkLocator::pngToDataUrl( const TQString & iconPath )
TQByteArray ba = pngFile.readAll();
pngFile.close();
return TQString::tqfromLatin1("data:image/png;base64,%1")
- .arg( KCodecs::base64Encode( ba ) );
+ .tqarg( KCodecs::base64Encode( ba ).data() );
}
@@ -422,7 +422,7 @@ TQString LinkLocator::getEmoticon()
// for copy & paste) representing the smiley
htmlRep = TQString("<img class=\"pimsmileyimg\" src=\"%1\" "
"alt=\"%2\" title=\"%3\" width=\"16\" height=\"16\"/>")
- .arg( dataUrl,
+ .tqarg( dataUrl,
TQStyleSheet::escape( smiley ),
TQStyleSheet::escape( smiley ) );
}
@@ -445,7 +445,7 @@ TQString LinkLocator::highlightedText()
if ( ch != '/' && ch != '*' && ch != '_' )
return TQString();
- TQRegExp re = TQRegExp( TQString("\\%1([0-9A-Za-z]+)\\%2").arg( ch ).arg( ch ) );
+ TQRegExp re = TQRegExp( TQString("\\%1([0-9A-Za-z]+)\\%2").tqarg( ch ).tqarg( ch ) );
if ( re.search( mText, mPos ) == mPos ) {
uint length = re.matchedLength();
// there must be a whitespace after the closing formating symbol
diff --git a/libkdepim/overlaywidget.cpp b/libkdepim/overlaywidget.cpp
index 6ffc06d3..77ce3410 100644
--- a/libkdepim/overlaywidget.cpp
+++ b/libkdepim/overlaywidget.cpp
@@ -76,7 +76,7 @@ void OverlayWidget::setAlignWidget( TQWidget * w )
bool OverlayWidget::eventFilter( TQObject* o, TQEvent* e)
{
- if ( o == mAlignWidget &&
+ if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(mAlignWidget) &&
( e->type() == TQEvent::Move || e->type() == TQEvent::Resize ) ) {
reposition();
}
diff --git a/libkdepim/qutf7codec.cpp b/libkdepim/qutf7codec.cpp
index db6589cd..630dcaa2 100644
--- a/libkdepim/qutf7codec.cpp
+++ b/libkdepim/qutf7codec.cpp
@@ -183,7 +183,7 @@ public:
qWarning("TQUtf7Decoder: 8bit char found in input. "
"Parser has been re-initialized!");
resetParser();
- result += TQChar::replacement;
+ result += TQChar::tqreplacement;
continue;
}
diff --git a/libkdepim/sendsmsdialog.cpp b/libkdepim/sendsmsdialog.cpp
index 6a1e3541..d034fd73 100644
--- a/libkdepim/sendsmsdialog.cpp
+++ b/libkdepim/sendsmsdialog.cpp
@@ -68,13 +68,13 @@ void SendSMSDialog::updateMessageLength()
int length = mText->length();
if( length > 480 )
- mMessageLength->setText( TQString( "%1/%2 (%3)" ).arg( length ).arg( 500 ).arg( 4 ) );
+ mMessageLength->setText( TQString( "%1/%2 (%3)" ).tqarg( length ).tqarg( 500 ).tqarg( 4 ) );
else if( length > 320 )
- mMessageLength->setText( TQString( "%1/%2 (%3)" ).arg( length ).arg( 480 ).arg( 3 ) );
+ mMessageLength->setText( TQString( "%1/%2 (%3)" ).tqarg( length ).tqarg( 480 ).tqarg( 3 ) );
else if( length > 160 )
- mMessageLength->setText( TQString( "%1/%2 (%3)" ).arg( length ).arg( 320 ).arg( 2 ) );
+ mMessageLength->setText( TQString( "%1/%2 (%3)" ).tqarg( length ).tqarg( 320 ).tqarg( 2 ) );
else
- mMessageLength->setText( TQString( "%1/%2" ).arg( length ).arg( 160 ) );
+ mMessageLength->setText( TQString( "%1/%2" ).tqarg( length ).tqarg( 160 ) );
}
void SendSMSDialog::updateButtons()
diff --git a/libkdepim/statusbarprogresswidget.cpp b/libkdepim/statusbarprogresswidget.cpp
index 8ca46ff9..2b2ef1db 100644
--- a/libkdepim/statusbarprogresswidget.cpp
+++ b/libkdepim/statusbarprogresswidget.cpp
@@ -268,7 +268,7 @@ bool StatusbarProgressWidget::eventFilter( TQObject *, TQEvent *ev )
if ( ev->type() == TQEvent::MouseButtonPress ) {
TQMouseEvent *e = (TQMouseEvent*)ev;
- if ( e->button() == LeftButton && mode != None ) { // toggle view on left mouse button
+ if ( e->button() == Qt::LeftButton && mode != None ) { // toggle view on left mouse button
// Consensus seems to be that we should show/hide the fancy dialog when the user
// clicks anywhere in the small one.
mProgressDialog->slotToggleVisibility();
diff --git a/libkdepim/addresseeview.cpp b/libkdepim/addresseeview.cpp
index d8ead42b..f291e4e1 100644
--- a/libkdepim/addresseeview.cpp
+++ b/libkdepim/addresseeview.cpp
@@ -151,11 +151,11 @@ void AddresseeView::enableLinks( int linkMask )
TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *proxy, LinkMask linkMask,
bool internalLoading, FieldMask fieldMask )
{
- TQString image = TQString( "contact_%1_image" ).arg( addr.uid() );
+ TQString image = TQString( "contact_%1_image" ).tqarg( addr.uid() );
// Style strings from Gentix; this is just an initial version.
//
// These will be substituted into various HTML strings with .arg().
// Search for @STYLE@ to find where. Note how we use %1 as a
// placeholder where we fill in something else (in this case,
// the global background color).
@@ -165,12 +165,12 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
"style=\""
"padding-right: 2px; "
"border-right: #000 dashed 1px; "
- "background: %1;\"").arg(backgroundColor);
+ "background: %1;\"").tqarg(backgroundColor);
TQString backgroundColor2 = KGlobalSettings::baseColor().name();
TQString cellStyle2 = TQString::tqfromLatin1(
"style=\""
"padding-left: 2px; "
- "background: %1;\"").arg(backgroundColor2);
+ "background: %1;\"").tqarg(backgroundColor2);
TQString tableStyle = TQString::tqfromLatin1(
"style=\""
"border: solid 1px; "
@@ -216,8 +216,8 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( date.isValid() )
dynamicPart += rowFmtStr
- .arg( KABC::Addressee::birthdayLabel() )
- .arg( KGlobal::locale()->formatDate( date, true ) );
+ .tqarg( KABC::Addressee::birthdayLabel() )
+ .tqarg( KGlobal::locale()->formatDate( date, true ) );
}
if ( fieldMask & PhoneFields ) {
@@ -235,15 +235,15 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & PhoneLinks ) {
TQString smsURL;
if ( (*phoneIt).type() & KABC::PhoneNumber::Cell )
- smsURL = TQString(" (<a href=\"sms:%1\">%2</a>)" ).arg( number ).arg( i18n( "SMS") );
+ smsURL = TQString(" (<a href=\"sms:%1\">%2</a>)" ).tqarg( number ).tqarg( i18n( "SMS") );
dynamicPart += rowFmtStr
- .arg( (*phoneIt).typeLabel().tqreplace( " ", "&nbsp;" ) )
- .arg( TQString::tqfromLatin1( "<a href=\"%1\">%2</a>%3" ).arg( url ).arg( number ).arg( smsURL ) );
+ .tqarg( (*phoneIt).typeLabel().tqreplace( " ", "&nbsp;" ) )
+ .tqarg( TQString::tqfromLatin1( "<a href=\"%1\">%2</a>%3" ).tqarg( url ).tqarg( number ).tqarg( smsURL ) );
} else {
dynamicPart += rowFmtStr
- .arg( (*phoneIt).typeLabel().tqreplace( " ", "&nbsp;" ) )
- .arg( number );
+ .tqarg( (*phoneIt).typeLabel().tqreplace( " ", "&nbsp;" ) )
+ .tqarg( number );
}
}
}
@@ -257,11 +257,11 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
TQUrl::encode( fullEmail );
if ( linkMask & EmailLinks ) {
- dynamicPart += rowFmtStr.arg( type )
- .arg( TQString::tqfromLatin1( "<a href=\"mailto:%1\">%2</a>" )
- .arg( fullEmail, TQStyleSheet::escape( *emailIt ) ) );
+ dynamicPart += rowFmtStr.tqarg( type )
+ .tqarg( TQString::tqfromLatin1( "<a href=\"mailto:%1\">%2</a>" )
+ .tqarg( fullEmail, TQStyleSheet::escape( *emailIt ) ) );
} else {
- dynamicPart += rowFmtStr.arg( type ).arg( *emailIt );
+ dynamicPart += rowFmtStr.tqarg( type ).tqarg( *emailIt );
}
}
}
@@ -276,7 +276,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
} else {
url = addr.url().prettyURL();
}
- dynamicPart += rowFmtStr.arg( i18n("Homepage") ).arg( url );
+ dynamicPart += rowFmtStr.tqarg( i18n("Homepage") ).tqarg( url );
}
TQString blog = addr.custom( "KADDRESSBOOK", "BlogFeed" );
@@ -284,7 +284,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & URLLinks ) {
blog = KStringHandler::tagURLs( blog );
}
- dynamicPart += rowFmtStr.arg( i18n("Blog Feed") ).arg( blog );
+ dynamicPart += rowFmtStr.tqarg( i18n("Blog Feed") ).tqarg( blog );
}
}
@@ -303,12 +303,12 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & AddressLinks ) {
dynamicPart += rowFmtStr
- .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .arg( link );
+ .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .tqarg( link );
} else {
dynamicPart += rowFmtStr
- .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .arg( formattedAddress );
+ .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .tqarg( formattedAddress );
}
} else {
TQString link = "<a href=\"addr:" + (*addrIt).id() + "\">" +
@@ -316,12 +316,12 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & AddressLinks ) {
dynamicPart += rowFmtStr
- .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .arg( link );
+ .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .tqarg( link );
} else {
dynamicPart += rowFmtStr
- .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .arg( (*addrIt).label().tqreplace( '\n', "<br>" ) );
+ .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .tqarg( (*addrIt).label().tqreplace( '\n', "<br>" ) );
}
}
}
@@ -333,7 +333,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
// the data afterwards (keeps us safe from possible % signs
// in either one).
notes = TQStyleSheet::escape( addr.note() );
- notes = rowFmtStr.arg( i18n( "Notes" ) ).arg( notes.tqreplace( '\n', "<br>" ) ) ;
+ notes = rowFmtStr.tqarg( i18n( "Notes" ) ).tqarg( notes.tqreplace( '\n', "<br>" ) ) ;
}
TQString customData;
@@ -371,7 +371,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( keyIt != titleMap.end() )
key = keyIt.data();
- customData += rowFmtStr.arg( key ).arg( TQStyleSheet::escape( value ) ) ;
+ customData += rowFmtStr.tqarg( key ).tqarg( TQStyleSheet::escape( value ) ) ;
}
}
}
@@ -385,7 +385,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
const TQString imAddress = addr.custom( "KADDRESSBOOK", "X-IMAddress" );
if ( !imAddress.isEmpty() ) {
- customData += rowFmtStr.arg( i18n( "IM Address" ) ).arg( TQStyleSheet::escape( imAddress ) ) ;
+ customData += rowFmtStr.tqarg( i18n( "IM Address" ) ).tqarg( TQStyleSheet::escape( imAddress ) ) ;
}
if ( proxy ) {
@@ -393,7 +393,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
// set image source to either a TQMimeSourceFactory key or a data:/ URL
TQString imgSrc;
if ( internalLoading ) {
- imgSrc = TQString::tqfromLatin1( "im_status_%1_image").arg( addr.uid() );
+ imgSrc = TQString::tqfromLatin1( "im_status_%1_image").tqarg( addr.uid() );
TQMimeSourceFactory::defaultFactory()->setPixmap( imgSrc, proxy->presenceIcon( addr.uid() ) );
} else
imgSrc = pixmapAsDataUrl( proxy->presenceIcon( addr.uid() ) );
@@ -407,10 +407,10 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
// append our status to the rest of the dynamic part of the addressee
dynamicPart += rowFmtStr
- .arg( i18n( "Presence" ) )
- .arg( imtqStatus
- .arg( imgSrc )
- .arg( proxy->presenceString( addr.uid() ) )
+ .tqarg( i18n( "Presence" ) )
+ .tqarg( imtqStatus
+ .tqarg( imgSrc )
+ .tqarg( proxy->presenceString( addr.uid() ) )
);
}
}
@@ -424,44 +424,44 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
TQString strAddr = TQString::tqfromLatin1(
"<div align=\"center\">"
"<table cellpadding=\"1\" cellspacing=\"0\" %1>"
- "<tr>").arg(tableStyle);
+ "<tr>").tqarg(tableStyle);
strAddr.append( TQString::tqfromLatin1(
"<td align=\"right\" valign=\"top\" width=\"30%\" rowspan=\"3\" %2>")
- .arg( cellStyle ) );
+ .tqarg( cellStyle ) );
strAddr.append( TQString::tqfromLatin1(
"<img src=\"%1\" width=\"50\" vspace=\"1\">" // image
"</td>")
- .arg( image ) );
+ .tqarg( image ) );
strAddr.append( TQString::tqfromLatin1(
"<td align=\"left\" width=\"70%\" %2>")
- .arg( cellStyle2 ) );
+ .tqarg( cellStyle2 ) );
strAddr.append( TQString::tqfromLatin1(
"<font size=\"+2\"><b>%2</b></font></td>" // name
"</tr>")
- .arg( name ) );
+ .tqarg( name ) );
strAddr.append( TQString::tqfromLatin1(
"<tr>"
"<td align=\"left\" width=\"70%\" %2>")
- .arg( cellStyle2 ) );
+ .tqarg( cellStyle2 ) );
strAddr.append( TQString::tqfromLatin1(
"%3</td>" // role
"</tr>")
- .arg( role ) );
+ .tqarg( role ) );
strAddr.append( TQString::tqfromLatin1(
"<tr>"
"<td align=\"left\" width=\"70%\" %2>")
- .arg( cellStyle2 ) );
+ .tqarg( cellStyle2 ) );
strAddr.append( TQString::tqfromLatin1(
"%4</td>" // organization
"</tr>")
- .arg( organization ) );
+ .tqarg( organization ) );
strAddr.append( TQString::tqfromLatin1(
"<tr><td %2>")
- .arg( cellStyle ) );
+ .tqarg( cellStyle ) );
strAddr.append( TQString::tqfromLatin1(
"&nbsp;</td><td %2>&nbsp;</td></tr>")
- .arg( cellStyle2 ) );
+ .tqarg( cellStyle2 ) );
strAddr.append( dynamicPart );
strAddr.append( notes );
strAddr.append( customData );
@@ -476,7 +476,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( !label.isEmpty() )
addrBookName = label;
}
- strAddr.append( i18n( "<p><b>Address book</b>: %1</p>" ).arg( addrBookName ) );
+ strAddr.append( i18n( "<p><b>Address book</b>: %1</p>" ).tqarg( addrBookName ) );
}
return strAddr;
}
@@ -532,11 +532,11 @@ void AddresseeView::updateView()
"%3" // dynamic part
"</body>"
"</html>" )
- .arg( KGlobalSettings::textColor().name() )
- .arg( KGlobalSettings::baseColor().name() )
- .arg( strAddr );
+ .tqarg( KGlobalSettings::textColor().name() )
+ .tqarg( KGlobalSettings::baseColor().name() )
+ .tqarg( strAddr );
- TQString imageURL = TQString( "contact_%1_image" ).arg( mAddressee.uid() );
+ TQString imageURL = TQString( "contact_%1_image" ).tqarg( mAddressee.uid() );
KABC::Picture picture = mAddressee.photo();
if ( picture.isIntern() && !picture.data().isNull() )
@@ -544,7 +544,7 @@ void AddresseeView::updateView()
else {
if ( !picture.url().isEmpty() ) {
if ( mImageData.count() > 0 )
- TQMimeSourceFactory::defaultFactory()->setImage( imageURL, mImageData );
+ TQMimeSourceFactory::defaultFactory()->setImage( imageURL, TQImage(mImageData) );
else {
mImageJob = KIO::get( KURL( picture.url() ), false, false );
connect( mImageJob, TQT_SIGNAL( data( KIO::Job*, const TQByteArray& ) ),
@@ -690,27 +690,27 @@ void AddresseeView::slotHighlighted( const TQString &link )
TQString email = link.mid( 7 );
emit emailHighlighted( email );
- emit highlightedMessage( i18n( "Send mail to '%1'" ).arg( email ) );
+ emit highlightedMessage( i18n( "Send mail to '%1'" ).tqarg( email ) );
} else if ( link.startsWith( "phone:" ) ) {
TQString number = link.mid( 8 );
emit phoneNumberHighlighted( strippedNumber( number ) );
- emit highlightedMessage( i18n( "Call number %1" ).arg( number ) );
+ emit highlightedMessage( i18n( "Call number %1" ).tqarg( number ) );
} else if ( link.startsWith( "fax:" ) ) {
TQString number = link.mid( 6 );
emit faxNumberHighlighted( strippedNumber( number ) );
- emit highlightedMessage( i18n( "Send fax to %1" ).arg( number ) );
+ emit highlightedMessage( i18n( "Send fax to %1" ).tqarg( number ) );
} else if ( link.startsWith( "addr:" ) ) {
emit highlightedMessage( i18n( "Show address on map" ) );
} else if ( link.startsWith( "sms:" ) ) {
TQString number = link.mid( 6 );
- emit highlightedMessage( i18n( "Send SMS to %1" ).arg( number ) );
+ emit highlightedMessage( i18n( "Send SMS to %1" ).tqarg( number ) );
} else if ( link.startsWith( "http:" ) || link.startsWith( "https:" ) ) {
emit urlHighlighted( link );
- emit highlightedMessage( i18n( "Open URL %1" ).arg( link ) );
+ emit highlightedMessage( i18n( "Open URL %1" ).tqarg( link ) );
} else if ( link.startsWith( "im:" ) ) {
- emit highlightedMessage( i18n( "Chat with %1" ).arg( mAddressee.realName() ) );
+ emit highlightedMessage( i18n( "Chat with %1" ).tqarg( mAddressee.realName() ) );
} else
emit highlightedMessage( "" );
}
@@ -151,11 +151,11 @@ void AddresseeView::enableLinks( int linkMask )
// Style strings from Gentix; this is just an initial version.
//
- // These will be substituted into various HTML strings with .arg().
+ // These will be substituted into various HTML strings with .tqarg().
// Search for @STYLE@ to find where. Note how we use %1 as a
// placeholder where we fill in something else (in this case,